Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(468)

Unified Diff: runtime/vm/class_finalizer.h

Issue 11232071: Ambiguous references do not necessarily cause compilation errors (issue 5736). (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/class_finalizer.cc » ('j') | runtime/vm/parser.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/class_finalizer.h
===================================================================
--- runtime/vm/class_finalizer.h (revision 13985)
+++ runtime/vm/class_finalizer.h (working copy)
@@ -49,12 +49,15 @@
FinalizationKind finalization);
// Allocate, finalize, and return a new malformed type as if it was declared
- // in class cls at the given token position. Build the error message from the
- // format string and its arguments.
- static RawType* NewFinalizedMalformedType(const Class& cls,
+ // in class cls at the given token position.
+ // If not null, prepend prev_error to the error message built from the format
+ // string and its arguments.
+ static RawType* NewFinalizedMalformedType(const Error& prev_error,
+ const Class& cls,
intptr_t type_pos,
+ FinalizationKind finalization,
const char* format, ...)
- PRINTF_ATTRIBUTE(3, 4);
+ PRINTF_ATTRIBUTE(5, 6);
// Depending on the given type, finalization mode, and execution mode, mark
// the given type as malformed or report a compile time error.
« no previous file with comments | « no previous file | runtime/vm/class_finalizer.cc » ('j') | runtime/vm/parser.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698